import { a as _defineProperty, I as BackgroundVariant, _ as _slicedToArray, b as useStore } from './index-998009d9.js';
import React, { memo, useRef, useState, useEffect } from 'react';
import cc from 'classcat';
import 'zustand';
import 'zustand/context';
import 'd3-zoom';

var createGridLinesPath = function createGridLinesPath(size, strokeWidth, stroke) {
  return /*#__PURE__*/React.createElement("path", {
    stroke: stroke,
    strokeWidth: strokeWidth,
    d: "M".concat(size / 2, " 0 V").concat(size, " M0 ").concat(size / 2, " H").concat(size)
  });
};
var createGridDotsPath = function createGridDotsPath(size, fill) {
  return /*#__PURE__*/React.createElement("circle", {
    cx: size,
    cy: size,
    r: size,
    fill: fill
  });
};

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var defaultColors = _defineProperty(_defineProperty({}, BackgroundVariant.Dots, '#81818a'), BackgroundVariant.Lines, '#eee');
var transformSelector = function transformSelector(s) {
  return s.transform;
};
var Background = function Background(_ref) {
  var _ref$variant = _ref.variant,
    variant = _ref$variant === void 0 ? BackgroundVariant.Dots : _ref$variant,
    _ref$gap = _ref.gap,
    gap = _ref$gap === void 0 ? 15 : _ref$gap,
    _ref$size = _ref.size,
    size = _ref$size === void 0 ? 0.4 : _ref$size,
    color = _ref.color,
    style = _ref.style,
    className = _ref.className;
  var ref = useRef(null);
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    patternId = _useState2[0],
    setPatternId = _useState2[1];
  var _useStore = useStore(transformSelector),
    _useStore2 = _slicedToArray(_useStore, 3),
    tX = _useStore2[0],
    tY = _useStore2[1],
    tScale = _useStore2[2];
  useEffect(function () {
    // when there are multiple flows on a page we need to make sure that every background gets its own pattern.
    var bgs = document.querySelectorAll('.react-flow__background');
    var index = Array.from(bgs).findIndex(function (bg) {
      return bg === ref.current;
    });
    setPatternId("pattern-".concat(index));
  }, []);
  var scaledGap = gap * tScale || 1;
  var xOffset = tX % scaledGap;
  var yOffset = tY % scaledGap;
  var isLines = variant === BackgroundVariant.Lines;
  var bgColor = color ? color : defaultColors[variant];
  var path = isLines ? createGridLinesPath(scaledGap, size, bgColor) : createGridDotsPath(size * tScale, bgColor);
  return /*#__PURE__*/React.createElement("svg", {
    className: cc(['react-flow__background', 'react-flow__container', className]),
    style: _objectSpread(_objectSpread({}, style), {}, {
      width: '100%',
      height: '100%'
    }),
    ref: ref
  }, patternId && (/*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("pattern", {
    id: patternId,
    x: xOffset,
    y: yOffset,
    width: scaledGap,
    height: scaledGap,
    patternUnits: "userSpaceOnUse"
  }, path), /*#__PURE__*/React.createElement("rect", {
    x: "0",
    y: "0",
    width: "100%",
    height: "100%",
    fill: "url(#".concat(patternId, ")")
  }))));
};
Background.displayName = 'Background';
var index = /*#__PURE__*/memo(Background);

export { index as default };
//# sourceMappingURL=index3.js.map
